@@ -27,6 +27,7 @@ package bartMachine;
 import java.util.Arrays;
 
 import OpenSourceExtensions.MersenneTwisterFast;
+import gnu.trove.list.array.TDoubleArrayList;
 import it.unimi.dsi.fastutil.doubles.DoubleArrayList;
 import it.unimi.dsi.fastutil.ints.IntArrayList;
 
@@ -65,36 +66,7 @@ public class StatToolbox {
 		return mu + Math.sqrt(sigsq) * std_norm_realization;
 	}
 	
-	// constants for the {@link normal_cdf} function
-    private static double NORM_CDF_a1 =  0.254829592;
-    private static double NORM_CDF_a2 = -0.284496736;
-    private static double NORM_CDF_a3 =  1.421413741;
-    private static double NORM_CDF_a4 = -1.453152027;
-    private static double NORM_CDF_a5 =  1.061405429;
-    private static double NORM_CDF_p  =  0.3275911;	
-	
-    /**
-     * Calculate the cumulative density under a standard normal to a point of interest.
-     *      
-     * @param x	The point of interest on the standard normal density support
-     * @return	The probability of interest
-     * 
-     * @see {@link http://www.johndcook.com/cpp_phi.html}
-     */
-	public static double normal_cdf(double x) {
-	    // Save the sign of x
-	    int sign = 1;
-	    if (x < 0){
-	        sign = -1;
-	    }
-	    x = Math.abs(x) / Math.sqrt(2.0);
 
-	    // A&S formula 7.1.26
-	    double t = 1.0 / (1.0 + NORM_CDF_p * x);
-	    double y = 1.0 - (((((NORM_CDF_a5 * t + NORM_CDF_a4) * t) + NORM_CDF_a3) * t + NORM_CDF_a2) * t + NORM_CDF_a1) * t * Math.exp(-x * x);
-
-	    return 0.5 * (1.0 + sign * y);
-	}
 	
 	/**
 	 * Compute the sample average of a vector of data
@@ -116,6 +88,13 @@ public class StatToolbox {
 	 * @param y	The vector of data values
 	 * @return	The sample average
 	 */
+	public static final double sample_average(TDoubleArrayList y){
+		double y_bar = 0;
+		for (int i = 0; i < y.size(); i++){
+			y_bar += y.get(i);
+		}
+		return y_bar / (double)y.size();
+	}	
 	public static final double sample_average(DoubleArrayList y){
 		double y_bar = 0;
 		for (int i = 0; i < y.size(); i++){
@@ -328,6 +307,6 @@ public class StatToolbox {
 	 * @return	A random number drawn from a uniform distirbution bounded between 0 and 1.
 	 */
 	public static double rand(){
-		return R.nextDouble();
+		return R.nextDouble(false, false);
 	}	
 }
